@@ -6,7 +6,8 @@ from PyQt5.QtCore import Qt
 from PyQt5.QtGui import QIcon
 from matplotlib.figure import Figure
 import numpy as np
-from .Imagen import Qt_Figure_Imagen
+from Dosepy.GUILayouts.Imagen import Qt_Figure_Imagen
+#from .Imagen import Qt_Figure_Imagen
 import pkg_resources
 import os
 import Dosepy.dose as dp
@@ -187,8 +188,15 @@ class MostrarLabels(QWidget):
                 #self.Resolution.setReadOnly(True)
 
                 if self.Eval_npy.shape != self.Refer_npy.shape:
-                    QMessageBox().critical(self, "Error", "No es posible el cálculo con matrices de diferente tamaño.", QMessageBox.Ok, QMessageBox.Ok)
-                    #raise Exception("No es posible el cálculo con matrices de diferente tamaño.")
+                    QMessageBox().critical(
+                    self,
+                    "Error",
+                    """No es posible el análisis con matrices de diferente tamaño.\n
+                    Referencia: {}\n
+                    A evaluar: {}""".format(self.Refer_npy.shape, self.Eval_npy.shape),
+                    QMessageBox.Ok, QMessageBox.Ok
+                    )
+
                 else:
                     self.Eval_button.setStyleSheet("background-color: rgb(88,200,138)")
                     self.Formatos_ok = True
@@ -198,8 +206,14 @@ class MostrarLabels(QWidget):
                 self.Eval_npy = np.genfromtxt(file_name_Evaluacion, delimiter = ',')
 
                 if self.Eval_npy.shape != self.Refer_npy.shape:
-                    QMessageBox().critical(self, "Error", "No es posible el cálculo con matrices de diferente tamaño.", QMessageBox.Ok, QMessageBox.Ok)
-                    #raise Exception("No es posible el cálculo con matrices de diferente tamaño.")
+                    QMessageBox().critical(
+                    self,
+                    "Error",
+                    """No es posible el análisis con matrices de diferente tamaño.\n
+                    Referencia: {}\n
+                    A evaluar: {}""".format(self.Refer_npy.shape, self.Eval_npy.shape),
+                    QMessageBox.Ok, QMessageBox.Ok
+                    )
 
                 else:
                     self.Eval_button.setStyleSheet("background-color: rgb(88,200,138)")
